@@ -1,7 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
+ * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -43,12 +43,12 @@ public class ColorPicker extends Button {
 	 * Construct a ColorPicker using a handle to a native resource.
 	 */
 	public ColorPicker(int handle) {
-		super(handle);
+		setHandle(handle);
 	}
 
 	protected void noopInit() {
-		if (-1 == handle) {
-			handle = gnome_color_picker_new();
+		if (-1 == getHandle()) {
+			setHandle(gnome_color_picker_new());
 			initializeEventHandlers();
 		}
 	}
@@ -63,7 +63,7 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 
 		return alpha[0];
 	}
@@ -78,7 +78,7 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 
 		return blue[0];
 	}
@@ -94,7 +94,7 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 
 		return green[0];
 	}
@@ -109,7 +109,7 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 
 		return red[0];
 	}
@@ -124,7 +124,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 
 		return alpha[0];
 	}
@@ -139,7 +139,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 
 		return blue[0];
 	}
@@ -154,7 +154,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 
 		return green[0];
 	}
@@ -169,7 +169,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 
 		return red[0];
 	}
@@ -184,7 +184,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 
 		return alpha[0];
 	}
@@ -199,7 +199,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 
 		return blue[0];
 	}
@@ -215,7 +215,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 
 		return green[0];
 	}
@@ -230,7 +230,7 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 
 		return red[0];
 	}
@@ -240,7 +240,7 @@ public class ColorPicker extends Button {
 	 * @return True if alpha is used.  Otherwise, false.
 	 */
 	public boolean getAlphaEnabled() {
-		return gnome_color_picker_get_use_alpha(handle);
+		return gnome_color_picker_get_use_alpha(getHandle());
 	}
 
 	/**
@@ -248,7 +248,7 @@ public class ColorPicker extends Button {
 	 * @return True if dither is used.  Otherwise, false.
 	 */
 	public boolean getDitherEnabled() {
-		return gnome_color_picker_get_dither(handle);
+		return gnome_color_picker_get_dither(getHandle());
 	}
 
 	/**
@@ -256,7 +256,7 @@ public class ColorPicker extends Button {
 	 * @return The title for the color picker.
 	 */
 	public String getTitle() {
-		return gnome_color_picker_get_title(handle);
+		return gnome_color_picker_get_title(getHandle());
 	}
 
 	/**
@@ -284,7 +284,7 @@ public class ColorPicker extends Button {
 				"The value " + red + " is outside the acceptable range of 0.0 to 1.0 for red.");
 		}
 
-		gnome_color_picker_set_d(handle, red, green, blue, alpha);
+		gnome_color_picker_set_d(getHandle(), red, green, blue, alpha);
 	}
 
 	/**
@@ -304,9 +304,9 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, a);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, a);
 		a[0] = alpha;
-		gnome_color_picker_set_d(handle, red[0], green[0], blue[0], a[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], a[0]);
 	}
 
 	/**
@@ -326,9 +326,9 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 		blue[0] = color;
-		gnome_color_picker_set_d(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -349,9 +349,9 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 		green[0] = color;
-		gnome_color_picker_set_d(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -371,9 +371,9 @@ public class ColorPicker extends Button {
 		double green[] = new double[1];
 		double red[] = new double[1];
 
-		gnome_color_picker_get_d(handle, red, green, blue, alpha);
+		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 		red[0] = color;
-		gnome_color_picker_set_d(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -401,7 +401,7 @@ public class ColorPicker extends Button {
 				"The value " + red + " is outside the acceptable range of 0 to 255 for red.");
 		}
 
-		gnome_color_picker_set_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_set_i8(getHandle(), red, green, blue, alpha);
 	}
 
 	/**
@@ -420,9 +420,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, a);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, a);
 		a[0] = alpha;
-		gnome_color_picker_set_i8(handle, red[0], green[0], blue[0], a[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], a[0]);
 	}
 
 	/**
@@ -441,9 +441,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 		blue[0] = color;
-		gnome_color_picker_set_i8(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -462,9 +462,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 		green[0] = color;
-		gnome_color_picker_set_i8(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -483,9 +483,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 		red[0] = color;
-		gnome_color_picker_set_i8(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -513,7 +513,7 @@ public class ColorPicker extends Button {
 				"The value " + red + " is outside the acceptable range of 0 to 65535 for red.");
 		}
 
-		gnome_color_picker_set_i8(handle, red, green, blue, alpha);
+		gnome_color_picker_set_i8(getHandle(), red, green, blue, alpha);
 	}
 
 	/**
@@ -533,9 +533,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, a);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, a);
 		a[0] = alpha;
-		gnome_color_picker_set_i16(handle, red[0], green[0], blue[0], a[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], a[0]);
 	}
 
 	/**
@@ -555,9 +555,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 		blue[0] = color;
-		gnome_color_picker_set_i16(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -578,9 +578,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 		green[0] = color;
-		gnome_color_picker_set_i16(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -600,9 +600,9 @@ public class ColorPicker extends Button {
 		int green[] = new int[1];
 		int red[] = new int[1];
 
-		gnome_color_picker_get_i16(handle, red, green, blue, alpha);
+		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 		red[0] = color;
-		gnome_color_picker_set_i16(handle, red[0], green[0], blue[0], alpha[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
@@ -610,7 +610,7 @@ public class ColorPicker extends Button {
 	 * @param enabled True to use alpha.  Otherwise, false.
 	 */
 	public void setAlphaEnabled(boolean enable) {
-		gnome_color_picker_set_use_alpha(handle, enable);
+		gnome_color_picker_set_use_alpha(getHandle(), enable);
 	}
 
 	/**
@@ -618,7 +618,7 @@ public class ColorPicker extends Button {
 	 * @param enable True to use dither.  Otherwise, false.
 	 */
 	public void setDitherEnabled(boolean enable) {
-		gnome_color_picker_set_dither(handle, enable);
+		gnome_color_picker_set_dither(getHandle(), enable);
 	}
 
 	/**
@@ -626,7 +626,7 @@ public class ColorPicker extends Button {
 	 * @param title The title for the color picker.
 	 */
 	public void setTitle(String title) {
-		gnome_color_picker_set_title(handle, title);
+		gnome_color_picker_set_title(getHandle(), title);
 	}
 
 	/**
